@@ -229,7 +229,10 @@ class AbstractBaseFlag(BaseModel):
         return None
 
     def _is_active_for_user(self, request):
-        return self.is_active_for_user(request.user)
+        user = getattr(request, "user", None)
+        if user:
+            return self.is_active_for_user(user)
+        return False
 
     def _is_active_for_language(self, request):
         if self.languages:
@@ -239,7 +242,7 @@ class AbstractBaseFlag(BaseModel):
                 return True
         return None
 
-    def is_active(self, request):
+    def is_active(self, request, read_only=False):
         if not self.pk:
             log_level = get_setting('LOG_MISSING_FLAGS')
             if log_level:
@@ -297,14 +300,19 @@ class AbstractBaseFlag(BaseModel):
 
             cookie = get_setting('COOKIE') % self.name
             if cookie in request.COOKIES:
-                flag_active = (request.COOKIES[cookie] == 'True')
-                set_flag(request, self.name, flag_active, self.rollout)
+                flag_active = request.COOKIES[cookie] == 'True'
+                if not read_only:
+                    set_flag(request, self.name, flag_active, self.rollout)
                 return flag_active
 
-            if Decimal(str(random.uniform(0, 100))) <= self.percent:
-                set_flag(request, self.name, True, self.rollout)
-                return True
-            set_flag(request, self.name, False, self.rollout)
+            if not read_only:
+                if Decimal(str(random.uniform(0, 100))) <= self.percent:
+                    set_flag(request, self.name, True, self.rollout)
+                    return True
+                set_flag(request, self.name, False, self.rollout)
+
+            else:
+                return None
 
         return False
 
@@ -401,7 +409,7 @@ class Flag(AbstractUserFlag):
         verbose_name_plural = _('Flags')
 
 
-class Switch(BaseModel):
+class AbstractBaseSwitch(BaseModel):
     """A feature switch.
 
     Switches are active, or inactive, globally.
@@ -442,6 +450,7 @@ class Switch(BaseModel):
     ALL_CACHE_KEY = 'ALL_SWITCHES_CACHE_KEY'
 
     class Meta:
+        abstract = True
         verbose_name = _('Switch')
         verbose_name_plural = _('Switches')
 
@@ -465,7 +474,7 @@ class Switch(BaseModel):
         return self.active
 
 
-class Sample(BaseModel):
+class AbstractBaseSample(BaseModel):
     """A sample of users.
 
     A sample is true some percentage of the time, but is not connected
@@ -509,6 +518,7 @@ class Sample(BaseModel):
     ALL_CACHE_KEY = 'ALL_SAMPLES_CACHE_KEY'
 
     class Meta:
+        abstract = True
         verbose_name = _('Sample')
         verbose_name_plural = _('Samples')
 
@@ -532,3 +542,28 @@ class Sample(BaseModel):
 
             return get_setting('SAMPLE_DEFAULT')
         return Decimal(str(random.uniform(0, 100))) <= self.percent
+
+
+class Switch(AbstractBaseSwitch):
+    """A feature switch.
+
+    Switches are active, or inactive, globally.
+
+    """
+    class Meta(AbstractBaseSwitch.Meta):
+        swappable = 'WAFFLE_SWITCH_MODEL'
+        verbose_name = _('Switch')
+        verbose_name_plural = _('Switches')
+
+
+class Sample(AbstractBaseSample):
+    """A sample of users.
+
+    A sample is true some percentage of the time, but is not connected
+    to users or requests.
+
+    """
+    class Meta(AbstractBaseSample.Meta):
+        swappable = 'WAFFLE_SAMPLE_MODEL'
+        verbose_name = _('Sample')
+        verbose_name_plural = _('Samples')
